@@ -13,5 +13,6 @@ from .sinks import InMemoryDocumentSink, FolderSink
 from .steps import NodeTagger, NodeTagCopy, TextParser, RollupTransformer, TagsToKeyValuePairExtractor
 from .stores import JsonDocumentStore, TableDataStore, DictDataStore, DataStoreHelper, LocalDocumentStore, \
     RemoteDocumentStore, RemoteTableDataStore, RemoteDictDataStore, RemoteModelStore, LocalModelStore
-from .taxonomy import Taxonomy
-from .workflow import Workflow, CronSchedule
+from .taxonomy import Taxonomy, Taxon, RemoteTaxonomy
+from .workflow import Workflow, CronSchedule, StorePublisher
+from .assistant import Assistant
\ No newline at end of file
